@@ -46,8 +46,10 @@ class BackgroundRemoval(SpanSelectorInSpectrum):
         default = 'Power Law')
     polynomial_order = t.Range(1,10)
     background_estimator = t.Instance(Component)
-    bg_line_range = t.Enum('from_left_range', 'full', 'ss_range', 
-        default = 'full')
+    bg_line_range = t.Enum('from_left_range',
+                           'full',
+                           'ss_range',
+                           default = 'full')
     hi = t.Int(0)
     view = tu.View(
         tu.Group(
@@ -106,7 +108,7 @@ class BackgroundRemoval(SpanSelectorInSpectrum):
         self.bg_line.autoscale = False
         self.bg_line.plot()
         
-    def bg_to_plot(self, axes_manager = None, fill_with = np.nan):
+    def bg_to_plot(self, axes_manager=None, fill_with=np.nan):
         # First try to update the estimation
         self.background_estimator.estimate_parameters(
             self.signal, self.ss_left_value, self.ss_right_value, 
@@ -143,24 +145,23 @@ class BackgroundRemoval(SpanSelectorInSpectrum):
             
     def apply(self):
         self.signal._plot.auto_update_plot = False
-        if self.signal.axes_manager.navigation_dimension != 0:
-            pbar = progressbar(
-            maxval = (np.cumprod(self.signal.axes_manager.navigation_shape)[-1]))
-            i = 0
-            self.bg_line_range = 'full'
-            indexes = np.ndindex(
-            tuple(self.signal.axes_manager.navigation_shape))
-            for index in indexes:
-                self.signal.axes_manager.set_not_slicing_indexes(index)
-                self.signal.data[
-                self.signal.axes_manager._getitem_tuple] -= \
-                np.nan_to_num(self.bg_to_plot(self.signal.axes_manager, 0))
-                i+=1
+        maxval = self.signal.axes_manager.navigation_size
+        if maxval > 0:
+            pbar = progressbar(maxval=maxval)
+        i = 0
+        self.bg_line_range = 'full'
+        for s in self.signal:
+            s.data[:] -= \
+            np.nan_to_num(self.bg_to_plot(self.signal.axes_manager,
+                                          0))
+            if self.background_type == 'Power Law':
+                s.data[:self.axis.value2index(self.ss_right_value)] = 0
+                
+            i+=1
+            if maxval > 0:
                 pbar.update(i)
+        if maxval > 0:
             pbar.finish()
-        else:
-            self.signal.data[self.signal.axes_manager._getitem_tuple] -= \
-                np.nan_to_num(self.bg_to_plot(self.signal.axes_manager, 0))
             
         self.signal._replot()
         self.signal._plot.auto_update_plot = True
@@ -228,8 +229,10 @@ class SpikesRemoval(SpanSelectorInSpectrum):
             show_border=True,
             label='Advanced settings'),
             ),
-            buttons= [OKButton, OurPreviousButton, OurFindButton, OurApplyButton,
-                      ],
+            buttons= [OKButton,
+                      OurPreviousButton,
+                      OurFindButton,
+                      OurApplyButton,],
             handler = SpikesRemovalHandler,
             title = 'Spikes removal tool')
                  
@@ -237,7 +240,9 @@ class SpikesRemoval(SpanSelectorInSpectrum):
         super(SpikesRemoval, self).__init__(signal)
         self.interpolated_line = None
         self.coordinates = [coordinate for coordinate in np.ndindex(
-                            tuple(signal.axes_manager.navigation_shape)) if (navigation_mask is None or not navigation_mask[coordinate])]
+                            tuple(signal.axes_manager.navigation_shape))
+                            if (navigation_mask is None or not 
+                                navigation_mask[coordinate])]
         self.signal = signal
         sys.setrecursionlimit(np.cumprod(self.signal.data.shape)[-1])
         self.line = signal._plot.signal_plot.ax_lines[0]
@@ -257,8 +262,8 @@ class SpikesRemoval(SpanSelectorInSpectrum):
         self.update_plot()
         
     def _show_derivative_histogram_fired(self):
-        self.signal.spikes_diagnosis(signal_mask=self.signal_mask,
-                                     navigation_mask=self.navigation_mask)
+        self.signal._spikes_diagnosis(signal_mask=self.signal_mask,
+                                navigation_mask=self.navigation_mask)
         
     def detect_spike(self):
         derivative = np.diff(self.signal())
@@ -275,8 +280,8 @@ class SpikesRemoval(SpanSelectorInSpectrum):
             return False
 
     def find(self, back=False):
-        if (self.index == len(self.coordinates) - 1 and back is False) \
-        or (back is True and self.index == 0):
+        if ((self.index == len(self.coordinates) - 1 and back is False)
+        or (back is True and self.index == 0)):
             messages.information('End of dataset reached')
             return
         if self.interpolated_line is not None:
@@ -294,8 +299,10 @@ class SpikesRemoval(SpanSelectorInSpectrum):
             minimum = max(0,self.argmax - 50)
             maximum = min(len(self.signal()) - 1, self.argmax + 50)
             self.ax.set_xlim(
-                self.signal.axes_manager.axes[-1].index2value(minimum),
-                self.signal.axes_manager.axes[-1].index2value(maximum))
+                self.signal.axes_manager.signal_axes[0].index2value(
+                    minimum),
+                self.signal.axes_manager.signal_axes[0].index2value(
+                    maximum))
             self.update_plot()
             self.create_interpolation_line()
 
@@ -356,6 +363,11 @@ class SpikesRemoval(SpanSelectorInSpectrum):
         else:
             left = axis.value2index(self.ss_left_value)
             right = axis.value2index(self.ss_right_value)
+        
+        # Clip to the axis dimensions
+        nchannels = self.signal.axes_manager.signal_shape[0]
+        left = left if left >= 0 else 0
+        right = right if right < nchannels else nchannels - 1
             
         return left,right
         
