@@ -42,6 +42,12 @@ OurApplyButton = tu.Action(name = "Apply",
 OurResetButton = tu.Action(name = "Reset",
                            action = "reset")
                            
+OurFindButton = tu.Action(name = "Find",
+                           action = "find")
+                           
+OurPreviousButton = tu.Action(name = "Previous",
+                           action = "back")
+                           
                 
 class SmoothingHandler(tu.Handler):
     def close(self, info, is_ok):
@@ -72,6 +78,16 @@ class SpanSelectorInSpectrumHandler(tu.Handler):
             obj.apply()
         
         return
+        
+    def next(self, info, *args, **kwargs):
+        """Handles the **Next** button being clicked.
+
+        """
+        obj = info.object
+        obj.is_ok = True
+        if hasattr(obj, 'next'):
+            obj.next()
+        return
 
 class SpectrumRangeSelectorHandler(tu.Handler):
     def close(self, info, is_ok):
@@ -123,7 +139,7 @@ class SpanSelectorInSpectrum(t.HasTraits):
          raise SignalOutputDimensionError(signal.axes.signal_dimension, 1)
         
         self.signal = signal
-        self.axis = self.signal.axes_manager._slicing_axes[0]
+        self.axis = self.signal.axes_manager.signal_axes[0]
         self.span_selector = None
         self.signal.plot()
         self.span_selector_switch(on = True)
@@ -137,7 +153,7 @@ class SpanSelectorInSpectrum(t.HasTraits):
         if on is True:
             self.span_selector = \
             drawing.widgets.ModifiableSpanSelector(
-            self.signal._plot.spectrum_plot.ax,
+            self.signal._plot.signal_plot.ax,
             onselect = self.update_span_selector_traits,
             onmove_callback = self.update_span_selector_traits)
 
@@ -151,6 +167,13 @@ class SpanSelectorInSpectrum(t.HasTraits):
         self.ss_left_value = self.span_selector.rect.get_x()
         self.ss_right_value = self.ss_left_value + \
             self.span_selector.rect.get_width()
+            
+    def reset_span_selector(self):
+        self.span_selector_switch(False)
+        self.ss_left_value = 0
+        self.ss_right_value = 0
+        self.span_selector_switch(True)
+        
 
 class SpectrumCalibration(SpanSelectorInSpectrum):
     left_value = t.Float(label = 'New left value')
@@ -225,15 +248,15 @@ class Smoothing(t.HasTraits):
         self.data_line = None
         self.smooth_line = None
         self.signal = signal
-        self.axis = self.signal.axes_manager._slicing_axes[0].axis
+        self.axis = self.signal.axes_manager.signal_axes[0].axis
         self.plot()
                    
     def plot(self):
         if self.signal._plot is None or not \
-            does_figure_object_exists(self.signal._plot.spectrum_plot.figure):
+            does_figure_object_exists(self.signal._plot.signal_plot.figure):
             self.signal.plot()
         hse = self.signal._plot
-        l1 = hse.spectrum_plot.ax_lines[0]
+        l1 = hse.signal_plot.ax_lines[0]
         self.original_color = l1.line.get_color()
         l1.line_properties_helper(self.original_color, 'scatter')
         l1.set_properties()
@@ -243,7 +266,7 @@ class Smoothing(t.HasTraits):
         l2.line_properties_helper(np.array(
             self.line_color.Get())/255., 'line')   
         # Add the line to the figure
-        hse.spectrum_plot.add_line(l2)
+        hse.signal_plot.add_line(l2)
         l2.plot()
         self.data_line = l1
         self.smooth_line = l2
@@ -256,12 +279,12 @@ class Smoothing(t.HasTraits):
         
     def turn_diff_line_on(self, diff_order):
 
-        self.signal._plot.spectrum_plot.create_right_axis()
+        self.signal._plot.signal_plot.create_right_axis()
         self.smooth_diff_line = drawing.spectrum.SpectrumLine()
         self.smooth_diff_line.data_function = self.diff_model2plot
         self.smooth_diff_line.line_properties_helper(np.array(
             self.line_color.Get())/255., 'line')   
-        self.signal._plot.spectrum_plot.add_line(self.smooth_diff_line,
+        self.signal._plot.signal_plot.add_line(self.smooth_diff_line,
                                                  ax = 'right')
         self.smooth_diff_line.axes_manager = self.signal.axes_manager
         
@@ -320,7 +343,7 @@ class Smoothing(t.HasTraits):
             pbar.update(i)
         pbar.finish()
         if self.differential_order > 0:
-            self.signal.axes_manager._slicing_axes[0].offset = \
+            self.signal.axes_manager.signal_axes[0].offset = \
                 self.smooth_diff_line.axis[0]
             self.signal.crop_in_pixels(-1,0,-self.differential_order)
         self.signal._replot()
@@ -456,7 +479,8 @@ class Load(t.HasTraits):
     traits_view = tu.View(
         tu.Group('filename'),
         kind = 'livemodal',
-        buttons = [OKButton, CancelButton])
+        buttons = [OKButton, CancelButton],
+        title = 'Load file')
         
 class ImageContrastHandler(tu.Handler):
     def close(self, info, is_ok):
