@@ -106,7 +106,8 @@ def load(filenames=None, record_by=None, signal_type=None,
         If True and multiple filenames are passed in, stacking all
         the data into a single object is attempted. All files must match
         in shape. It is possible to store the data in a memory mapped
-        temporary file instead of in memory setting mmap_mode.
+        temporary file instead of in memory setting mmap_mode. The title is set
+        to the name of the folder containing the files.
         
     mmap: bool
         If True and stack is True, then the data is stored
@@ -174,7 +175,8 @@ def load(filenames=None, record_by=None, signal_type=None,
         if stack is True:
             original_shape = None
             for i, filename in enumerate(filenames):
-                obj = load_single_file(filename, output_level=0,**kwds)
+                obj = load_single_file(filename, output_level=0,
+                    signal_type=signal_type, **kwds)
                 if original_shape is None:
                     original_shape = obj.data.shape
                     record_by = obj.mapped_parameters.record_by
@@ -204,10 +206,13 @@ def load(filenames=None, record_by=None, signal_type=None,
                     eaxis.name = 'stack_element'
                     eaxis.navigate = True
                     signal.mapped_parameters = obj.mapped_parameters
-                    signal.mapped_parameters.original_filename = ''
+                    # Get the title from the folder name
                     signal.mapped_parameters.title = \
-                    os.path.split(os.path.split(
-                        os.path.abspath(filenames[0]))[0])[1]
+                    os.path.split(
+                        os.path.split(
+                            os.path.abspath(filenames[0])
+                                     )[0]
+                                  )[1]
                     signal.original_parameters = DictionaryBrowser({})
                     signal.original_parameters.add_node('stack_elements')
                 if obj.data.shape != original_shape:
@@ -225,10 +230,11 @@ def load(filenames=None, record_by=None, signal_type=None,
                     obj.mapped_parameters.as_dictionary()
                 del obj
             messages.information('Individual files loaded correctly')
-            print signal
+            signal.print_summary()
             objects = [signal,]
         else:
-            objects=[load_single_file(filename, output_level=0,**kwds) 
+            objects=[load_single_file(filename, output_level=0,
+                     signal_type=signal_type, **kwds) 
                 for filename in filenames]
             
         if hyperspy.defaults_parser.preferences.General.plot_on_load:
@@ -239,7 +245,8 @@ def load(filenames=None, record_by=None, signal_type=None,
     return objects
 
 
-def load_single_file(filename, record_by=None, output_level=2, **kwds):
+def load_single_file(filename, record_by=None, output_level=2, 
+    signal_type=None, **kwds):
     """
     Load any supported file into an Hyperspy structure
     Supported formats: netCDF, msa, Gatan dm3, Ripple (rpl+raw)
@@ -269,17 +276,19 @@ def load_single_file(filename, record_by=None, output_level=2, **kwds):
         # Try to load it with the python imaging library
         reader = image
         try:
-            return load_with_reader(filename, reader, record_by, **kwds)
+            return load_with_reader(filename, reader, record_by, 
+                signal_type=signal_type, **kwds)
         except:
             messages.warning_exit('File type not supported')
     else:
         reader = io_plugins[i]
-        return load_with_reader(filename, reader, record_by, 
+        return load_with_reader(filename, reader, record_by,
+                    signal_type=signal_type,
                     output_level=output_level, **kwds)
 
 
-def load_with_reader(filename, reader, record_by = None, signal_type = None,
-                     output_level=1, **kwds):
+def load_with_reader(filename, reader, record_by=None,
+        signal_type=None, output_level=1, **kwds):
     from hyperspy.signals.image import Image
     from hyperspy.signals.spectrum import Spectrum
     from hyperspy.signals.eels import EELSSpectrum
@@ -287,7 +296,7 @@ def load_with_reader(filename, reader, record_by = None, signal_type = None,
         messages.information('Loading %s ...' % filename)
     
     file_data_list = reader.file_reader(filename,
-                                         record_by=record_by,
+                                        record_by=record_by,
                                         output_level=output_level,
                                         **kwds)
     objects = []
@@ -305,13 +314,19 @@ def load_with_reader(filename, reader, record_by = None, signal_type = None,
         if file_data_dict['mapped_parameters']['record_by'] == 'image':
             s = Image(file_data_dict)
         else:
-            if 'signal_type' in file_data_dict['mapped_parameters'] and \
-                file_data_dict['mapped_parameters']['signal_type'] == 'EELS':
+            if ('signal_type' in file_data_dict['mapped_parameters'] 
+                and file_data_dict['mapped_parameters']['signal_type'] 
+                == 'EELS'):
                 s = EELSSpectrum(file_data_dict)
             else:
                 s = Spectrum(file_data_dict)
+        folder, filename = os.path.split(os.path.abspath(filename))
+        filename, extension = os.path.splitext(filename)
+        s.tmp_parameters.folder = folder
+        s.tmp_parameters.filename = filename
+        s.tmp_parameters.extension = extension.replace('.','')
         objects.append(s)
-        print s
+        s.print_summary()
 
     if len(objects) == 1:
         objects = objects[0]
@@ -358,3 +373,8 @@ def save(filename, signal, overwrite=None, **kwds):
         if overwrite is True:
             writer.file_writer(filename, signal, **kwds)
             print('The %s file was created' % filename)
+            folder, filename = os.path.split(os.path.abspath(filename))
+            signal.tmp_parameters.set_item('folder', folder)
+            signal.tmp_parameters.set_item('filename', 
+                                           os.path.splitext(filename)[0])
+            signal.tmp_parameters.set_item('extension', extension)
