@@ -801,7 +801,7 @@ class DM3ImageFile(object):
             if name:
                 self.name = self.data_dict.ls([im,] + DM3ImageFile.imname)[1][1]
             else:
-                self.name = self.filename
+                self.name = ""
             #~ if self.output_level>1:
                 #~ print 'Loading image "%s" (ID: %i) from file %s'% (self.name,
                                                                #~ self.data_id,
@@ -822,7 +822,7 @@ class DM3ImageFile(object):
             
         self.old_code_tags = parseDM3(self.filename)
         self.SI_format = None
-        self.signal = None
+        self.signal = ""
         for tag, value in self.old_code_tags.iteritems():
             if 'Format' in tag and 'Spectrum image' in str(value):
                 self.SI_format = value
@@ -1205,7 +1205,7 @@ def file_reader(filename, record_by=None, order = None, data_id=1,
            'units' : unicode(units[i]),} \
            for i in xrange(dim)]
 
-    mapped_parameters['original_filename'] = filename
+    mapped_parameters['original_filename'] = os.path.split(filename)[1]
     mapped_parameters['record_by'] = dm3.record_by
     mapped_parameters['signal_type'] = dm3.signal
     original_parameters = {}
