@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with  Hyperspy.  If not, see <http://www.gnu.org/licenses/>.
 
+import copy
 import types
 import  math
 import glob
@@ -211,7 +212,7 @@ def _estimate_gain(ns, cs, weighted = False, higher_than = None,
         from hyperspy.model import Model
         from hyperspy.components import Line
         s = Spectrum({'data' : varso[avesoh]})
-        s.axes_manager._slicing_axes[0].axis = aveso[avesoh]
+        s.axes_manager.signal_axes[0].axis = aveso[avesoh]
         m = Model(s)
         l = Line()
         l.a.value = fit[1]
@@ -238,9 +239,9 @@ def _estimate_correlation_factor(g0, gk,k):
     c = (1 - e)**2
     return c    
 
-def estimate_variance_parameters(noisy_signal, clean_signal, mask = None,
-    pol_order = 1, higher_than = None, return_results = False,
-    plot_results = True, weighted = False):
+def estimate_variance_parameters(noisy_signal, clean_signal, mask=None,
+    pol_order=1, higher_than=None, return_results=False,
+    plot_results=True, weighted=False):
     """Find the scale and offset of the Poissonian noise
 
     By comparing an SI with its denoised version (i.e. by PCA), this plots an
@@ -249,7 +250,7 @@ def estimate_variance_parameters(noisy_signal, clean_signal, mask = None,
 
     Parameters
     ----------
-    noisy_SI, clean_SI : Spectrum instances
+    noisy_SI, clean_SI : spectrum.Spectrum instances
     mask : numpy bool array
         To define the channels that will be used in the calculation.
     pol_order : int
@@ -272,8 +273,8 @@ def estimate_variance_parameters(noisy_signal, clean_signal, mask = None,
     cs = clean_signal.data.copy()
 
     if mask is not None:
-        ns = ns[mask]
-        cs = cs[mask]
+        ns = ns[~mask]
+        cs = cs[~mask]
 
     results0 = _estimate_gain(ns, cs, weighted = weighted, 
         higher_than = higher_than, plot_results = plot_results, binning = 0,
@@ -1195,10 +1196,11 @@ class DictionaryBrowser(object):
         Parameters
         ----------
         item_path : Str
-            A string describing the path with each item separated by a point
+            A string describing the path with each item separated by 
+            full stops (periods)
             
-        Example
-        -------
+        Examples
+        --------
         
         >>> dict = {'To' : {'be' : True}}
         >>> dict_browser = DictionaryBrowser(dict)
@@ -1213,6 +1215,8 @@ class DictionaryBrowser(object):
         """
         if type(item_path) is str:
             item_path = item_path.split('.')
+        else:
+            item_path = copy.copy(item_path)
         attrib = item_path.pop(0)
         if hasattr(self, attrib):
             if len(item_path) == 0:
@@ -1225,9 +1229,60 @@ class DictionaryBrowser(object):
                     return False
         else:
             return False
+            
+    def set_item(self, item_path, value):
+        """Given the path and value, create the missing nodes in
+        the path and assign to the last one the value
+        
+        Parameters
+        ----------
+        item_path : Str
+            A string describing the path with each item separated by a 
+            full stops (periods)
+            
+        Examples
+        --------
+        
+        >>> dict_browser = DictionaryBrowser({})
+        >>> dict_browser.set_item('First.Second.Third', 3)
+        >>> dict_browser
+        └── First
+           └── Second
+                └── Third = 3
+        
+        """
+        if not self.has_item(item_path):
+            self.add_node(item_path)
+        if type(item_path) is str:
+            item_path = item_path.split('.')
+        if len(item_path) > 1:
+            self.__getattribute__(item_path.pop(0)).set_item(
+                item_path, value)
+        else:
+            self.__setattr__(item_path.pop(), value)
+
+
 
     def add_node(self, node_path):
-        keys = node_path.split('/')
+        """Adds all the nodes in the given path if they don't exist.
+        
+        Parameters
+        ----------
+        node_path: str
+            The nodes must be separated by full stops (periods).
+            
+        Examples
+        --------
+        
+        >>> dict_browser = DictionaryBrowser({})
+        >>> dict_browser.add_node('First.Second')
+        >>> dict_browser.First.Second = 3
+        >>> dict_browser
+        └── First
+            └── Second = 3
+
+        """
+        keys = node_path.split('.')
         for key in keys:
             if self.has_item(key) is False:
                 self[key] = DictionaryBrowser()
@@ -1499,3 +1554,44 @@ def strlist2enumeration(lst):
         return "%s and %s" % lst
     else:
         return "%s, "*(len(lst) - 2) % lst[:-2] + "%s and %s" % lst[-2:]
+        
+def get_array_memory_size_in_GiB(shape, dtype):
+    """Given the size and dtype returns the amount of memory that such
+    an array needs to allocate
+    
+    Parameters
+    ----------
+    shape: tuple
+    dtype : data-type
+        The desired data-type for the array.
+    """
+    if isinstance(dtype, str):
+        dtype = np.dtype(dtype)
+    return np.array(shape).cumprod()[-1] * dtype.itemsize / 2.**30
+    
+def symmetrize(a):
+    return a + a.swapaxes(0,1) - np.diag(a.diagonal())
+    
+def antisymmetrize(a):    
+    return a - a.swapaxes(0,1)+ np.diag(a.diagonal())
+    
+def get_linear_interpolation(p1, p2, x):
+    '''Given two points in 2D returns y for a given x for y = ax + b
+    
+    Parameters
+    ----------
+    p1,p2 : (x, y)
+    x : float
+    
+    Returns
+    -------
+    y : float
+    
+    '''  
+    x1, y1 =  p1
+    x2, y2 = p2
+    a = (y2 - y1) / (x2 - x1)
+    b = (x2 * y1 - x1 * y2) / (x2-x1)
+    y = a*x + b
+    return y
+
