@@ -83,6 +83,11 @@ class Model(list):
     @low_loss.setter
     def low_loss(self, value):
         if value is not None:
+            if (value.axes_manager.navigation_shape != 
+                self.spectrum.axes_manager.navigation_shape):
+                    raise ValueError('The low-loss does not have '
+                        'the same navigation dimension as the '
+                        'core-loss')
             self._low_loss = value
             self.set_convolution_axis()
             self.convolved = True
@@ -279,9 +284,10 @@ class Model(list):
         if switch_aap is True:
             self.set_auto_update_plot(False)
         for component in self:
-            component.charge_value_from_map(
-            tuple(self.axes_manager._indexes), only_fixed = 
-            only_fixed)
+            indexes = self.axes_manager._indexes
+            indexes = tuple(indexes) if indexes else (0,)
+            component.charge_value_from_map(indexes, only_fixed=
+                                            only_fixed)
         if switch_aap is True:
             self.set_auto_update_plot(True)
             self.update_plot()
@@ -1106,6 +1112,8 @@ class Model(list):
                 else:
                     print(component._id_name)
                 parameters = component.free_parameters if only_free \
-                    else component.parameter
+                    else component.parameters
                 for parameter in parameters:
-                    print("\t\t%s\t%f" % (parameter.name, parameter.value))
+                    if not hasattr(parameter.value, '__iter__'):
+                        print("\t\t%s\t%f" % (
+                            parameter.name, parameter.value))
