@@ -43,6 +43,7 @@ class Signal(t.HasTraits, MVA):
     axes_manager = t.Instance(AxesManager)
     original_parameters = t.Instance(DictionaryBrowser)
     mapped_parameters = t.Instance(DictionaryBrowser)
+    tmp_parameters = t.Instance(DictionaryBrowser)
     _default_record_by = 'image'
 
     def __init__(self, file_data_dict=None, *args, **kw):
@@ -57,6 +58,7 @@ class Signal(t.HasTraits, MVA):
         super(Signal, self).__init__()
         self.mapped_parameters = DictionaryBrowser()
         self.original_parameters = DictionaryBrowser()
+        self.tmp_parameters = DictionaryBrowser()
         self.learning_results=LearningResults()
         self.peak_learning_results=LearningResults()
         if file_data_dict is not None:
@@ -76,18 +78,20 @@ class Signal(t.HasTraits, MVA):
 
         return string
         
-    def __str__(self):
-        string = "\n\tTitle: %s"%self.mapped_parameters.title
+    def print_summary(self):
+        string = "\n\tTitle: "
+        string += self.mapped_parameters.title.decode('utf8')
         if hasattr(self.mapped_parameters,'signal_type'):
-            string += "\n\tSignal type: %s" % self.mapped_parameters.signal_type
-        string += "\n\tData dimensions: %s" % (str(self.data.shape))
+            string += "\n\tSignal type: "
+            string += self.mapped_parameters.signal_type
+        string += "\n\tData dimensions: "
+        string += str(self.data.shape)
         if hasattr(self.mapped_parameters, 'record_by'):
-            string += \
-            "\n\tData representation: %s" % self.mapped_parameters.record_by
-            string += \
-            "\n\tData type: %s" % self.data.dtype
-
-        return string
+            string += "\n\tData representation: "
+            string += self.mapped_parameters.record_by
+            string += "\n\tData type: "
+            string += str(self.data.dtype)
+        print string
 
     def load_dictionary(self, file_data_dict):
         """Parameters:
@@ -132,12 +136,7 @@ class Signal(t.HasTraits, MVA):
         self.mapped_parameters._load_dictionary(
             file_data_dict['mapped_parameters'])
         if not hasattr(self.mapped_parameters,'title'):
-            if hasattr(self.mapped_parameters,'original_filename'):
-                self.mapped_parameters.title = \
-                    os.path.splitext(self.mapped_parameters.original_filename)[0]
-            # "Synthetic" signals do not have an original filename
-            else:
-                self.mapped_parameters.title = ''
+            self.mapped_parameters.title = ''
         if not hasattr(self.mapped_parameters,'record_by'):
             self.mapped_parameters.record_by = self._default_record_by
         self.squeeze()
@@ -243,7 +242,11 @@ class Signal(t.HasTraits, MVA):
         
         self._plot.axes_manager = axes_manager
         self._plot.signal_data_function = self.__call__
-        self._plot.signal_title = self.mapped_parameters.title
+        if self.mapped_parameters.title:
+            self._plot.signal_title = self.mapped_parameters.title
+        elif self.tmp_parameters.has_item('filename'):
+            self._plot.signal_title = self.tmp_parameters.filename
+            
 
         # Navigator properties
         if self.axes_manager.navigation_axes:
@@ -264,7 +267,8 @@ class Signal(t.HasTraits, MVA):
             print "Object does not have any residual information.  Is it a \
 reconstruction created using either get_decomposition_model or get_bss_model methods?"
 
-    def save(self, filename=None, overwrite=None, **kwds):
+    def save(self, filename=None, overwrite=None, extension=None,
+             **kwds):
         """Saves the signal in the specified format.
 
         The function gets the format from the extension. You can use:
@@ -284,24 +288,32 @@ reconstruction created using either get_decomposition_model or get_bss_model met
         Parameters
         ----------
         filename : str or None
-            If None and mapped_parameters.filename or 
-            mapped_parameters.original_filename are defined, the
-            filename and extension will be taken from them in this 
-            order.
+            If None and tmp_parameters.filename and 
+            tmp_paramters.folder are defined, the
+            filename and extension will be taken from them.
         overwrite : None, bool
             If None, if the file exists it will query the user. If 
             True(False) it (does not) overwrites the file if it exists.
+        extension : str
+            The extension of the file that defines the file format, 
+            e.g. 'rpl'. It overwrite the extension given in filename
+            if any.
+            
         """
         if filename is None:
-            if self.mapped_parameters.has_item('filename'):
-                filename = self.mapped_parameters.filename
+            if (self.tmp_parameters.has_item('filename') and 
+                self.tmp_parameters.has_item('folder')):
+                filename = os.path.join(
+                    self.tmp_parameters.folder,
+                    self.tmp_parameters.filename + '.' +
+                    self.tmp_parameters.extension)
             elif self.mapped_parameters.has_item('original_filename'):
                 filename = self.mapped_parameters.original_filename
-                self.mapped_parameters.filename = \
-                    self.mapped_parameters.original_filename
             else:
                 raise ValueError('File name not defined')
-
+        if extension is not None:
+            basename, ext = os.path.splitext(filename)
+            filename = basename + '.' + extension
         io.save(filename, self, overwrite=overwrite, **kwds)
 
     def _replot(self):
@@ -774,10 +786,13 @@ reconstruction created using either get_decomposition_model or get_bss_model met
             return s
 
     def copy(self):
-        return(copy.copy(self))
+        return copy.copy(self)
 
     def deepcopy(self):
-        return(copy.deepcopy(self))
+        s = copy.deepcopy(self)
+        if self.data is not None:
+            s.data = s.data.copy()
+        return s
         
     def change_dtype(self, dtype):
         """Change the data type
@@ -791,7 +806,8 @@ reconstruction created using either get_decomposition_model or get_bss_model met
         Example
         -------
         >>> import numpy as np
-        >>> from hyperspy.signals.spectrum import Spectrum
+        >>> from hyperspy.signals.spectrum import Spectrum        ns = 
+        ns.data = self.data.copy()
         >>> s = signals.Spectrum({'data' : np.array([1,2,3,4,5])})
         >>> s.data
         array([1, 2, 3, 4, 5])
@@ -1788,12 +1804,63 @@ reconstruction created using either get_decomposition_model or get_bss_model met
                 print "Clipping the variance to the gaussian_noise_var"
                 self.variance = np.clip(self.variance, gaussian_noise_var,
                 np.Inf)
+                
+    def get_current_signal(self):
+        data = self.data
+        self.data = None
+        cs = self.deepcopy()
+        self.data = data
+        del data
+        cs.data = self()
+        for axis in cs.axes_manager.navigation_axes:
+            cs.axes_manager.axes.remove(axis)
+            cs.axes_manager.set_signal_dimension()
+        if cs.tmp_parameters.has_item('filename'):
+            basename = cs.tmp_parameters.filename
+            ext = cs.tmp_parameters.extension
+            cs.tmp_parameters.filename = (basename + '_' +
+                    str(self.axes_manager.coordinates) + '.' + ext)
+        cs.mapped_parameters.title = (cs.mapped_parameters.title +
+                    ' ' + str(self.axes_manager.coordinates))
+        return cs
+        
+    def _get_navigation_signal(self):
+        if self.axes_manager.navigation_dimension == 0:
+            return None
+        elif self.axes_manager.navigation_dimension == 1:
+            from hyperspy.signals.spectrum import Spectrum
+            s = Spectrum({
+                'data' : np.zeros(
+                    self.axes_manager.navigation_shape),
+                'axes' : self.axes_manager._get_navigation_axes_dicts()})
+        elif self.axes_manager.navigation_dimension == 2:
+            from hyperspy.signals.image import Image
+            s = Image({
+                'data' : np.zeros(
+                    self.axes_manager.navigation_shape),
+                'axes' : self.axes_manager._get_navigation_axes_dicts()})
+        else:
+            s = Signal({
+                'data' : np.zeros(
+                    self.axes_manager.navigation_shape),
+                'axes' : self.axes_manager._get_navigation_axes_dicts()})
+        return s
+                
+        
+    def __iter__(self):
+        return self
+        
+    def next(self):
+        self.axes_manager.next()
+        return self.get_current_signal()
+        
+    def __len__(self):
+        if self.axes_manager.navigation_size == 0:
+            return 1
+        else:
+            return self.axes_manager.navigation_size
+        
 
-#
-#    def get_single_spectrum(self):
-#        s = Spectrum({'calibration' : {'data_cube' : self()}})
-#        s.get_calibration_from(self)
-#        return s
 #
 #    def sum_every_n(self,n):
 #        """Bin a line spectrum
@@ -1854,39 +1921,4 @@ reconstruction created using either get_decomposition_model or get_bss_model met
 #        return sp
 
 
-#class SignalwHistory(Signal):
-#    def _get_cube(self):
-#        return self.__cubes[self.current_cube]['data']
-#
-#    def _set_cube(self,arg):
-#        self.__cubes[self.current_cube]['data'] = arg
-#    data_cube = property(_get_cube,_set_cube)
-#
-#    def __new_cube(self, cube, treatment):
-#        history = copy.copy(self.history)
-#        history.append(treatment)
-#        if self.backup_cubes:
-#            self.__cubes.append({'data' : cube, 'history': history})
-#        else:
-#            self.__cubes[-1]['data'] = cube
-#            self.__cubes[-1]['history'] = history
-#        self.current_cube = -1
-#
-#    def _get_history(self):
-#        return self.__cubes[self.current_cube]['history']
-#    def _set_treatment(self,arg):
-#        self.__cubes[self.current_cube]['history'].append(arg)
-#
-#    history = property(_get_history,_set_treatment)
-#
-#    def print_history(self):
-#        """Prints the history of the SI to the stdout"""
-#        i = 0
-#        print
-#        print "Cube\tHistory"
-#        print "----\t----------"
-#        print
-#        for cube in self.__cubes:
-#            print i,'\t', cube['history']
-#            i+=1
-#
+
