@@ -15,3 +15,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with  Hyperspy.  If not, see <http://www.gnu.org/licenses/>.
+
+from hyperspy.signals.spectrum import Spectrum
+from hyperspy.signals.image import Image
+from hyperspy.signals.eels import EELSSpectrum
+from hyperspy.signals.spectrum_simulation import SpectrumSimulation
+from hyperspy.signals.eels_spectrum_simulation import (
+    EELSSpectrumSimulation)
+
+
+
