@@ -106,6 +106,11 @@ class Spectrum(Signal):
             self.crop_in_units(axis, offset - mini)
         if maxi > 0:
             self.crop_in_units(axis, None, _axis[-1] - maxi)
+            
+        # TODO: in some cases the first and last channels are wrongly
+        # set to zero. Until we find the time to fix it the following
+        # line is a walkaround
+        self.crop_in_pixels(-1,1,-1)
 
     def interpolate_in_index_1D(self, axis, i1, i2, delta=3, **kwargs):
         axis = self.axes_manager.axes[axis]
@@ -175,6 +180,9 @@ class Spectrum(Signal):
         ref = self.data[reference_indexes][i1:i2]
         if interpolate is True:
             ref = utils.interpolate_1D(ip, ref)
+        maxval = self.axes_manager.navigation_size
+        pbar = progressbar.progressbar(maxval=maxval)
+        i = 0
         for dat, shift in zip(self.iterate_axis(axis.index_in_array),
                               utils.iterate_axis(shift_array,
                                                  axis.index_in_array)):
@@ -182,6 +190,9 @@ class Spectrum(Signal):
             if interpolate is True:
                 dat = utils.interpolate_1D(ip, dat)
             shift[:] = np.argmax(np.correlate(ref, dat,'full')) - len(ref) + 1
+            i+=1
+            pbar.update(i)
+        pbar.finish()
 
         if max_shift is not None:
             if interpolate is True:
@@ -435,8 +446,6 @@ class Spectrum(Signal):
         from hyperspy.signals.spectrum_simulation import SpectrumSimulation
         dic = self._get_signal_dict()
         signal_type = self.mapped_parameters.signal_type
-        if signal_type is None:
-            signal_type = ""
         dic['mapped_parameters']['signal_type'] = \
             signal_type + '_simulation'
         simu = SpectrumSimulation(dic)
@@ -530,3 +539,34 @@ class Spectrum(Signal):
         iaxis = self.axes_manager.signal_axes[0].index_in_array
         self.crop_in_units(axis=iaxis, x1=left_value, x2=right_value)
     
+    @auto_replot
+    def hanning_taper(self, side='both', channels=None, offset=0):
+        """Hanning taper
+        
+        Parameters
+        ----------
+        side : {'left', 'right', 'both'}
+        channels : {None, int}
+            The number of channels to taper. If None 5% of the total
+            number of channels are tapered.
+        offset : int
+        
+        """
+        if channels is None:
+            channels = int(round(len(self()) * 0.02))
+            if channels < 20:
+                channels = 20
+        dc = self.data
+        if side == 'left' or side == 'both':
+            dc[..., offset:channels+offset] *= (
+                np.hanning(2*channels)[:channels])
+            dc[...,:offset] *= 0. 
+        if side== 'right' or side == 'both':
+            if offset == 0:
+                rl = None
+            else:
+                rl = -offset
+            dc[..., -channels-offset:rl] *= (
+                np.hanning(2*channels)[-channels:])
+            if offset != 0:
+                dc[..., -offset:] *= 0.
